@@ -39,10 +39,10 @@ async def execute(
     image: Any,
     output_format: str,
     dpi: int,
-    lang: Optional[str],
     psm: int,
     oem: int,
     timeout: float,
+    lang: Optional[str] = None,
     user_words: Optional[str] = None,
     user_patterns: Optional[str] = None,
     tessdata_dir: Optional[str] = None,
@@ -55,10 +55,10 @@ async def _(
     image: str,
     output_format: str,
     dpi: int,
-    lang: Optional[str],
     psm: int,
     oem: int,
     timeout: float,
+    lang: Optional[str] = None,
     user_words: Optional[str] = None,
     user_patterns: Optional[str] = None,
     tessdata_dir: Optional[str] = None,
@@ -66,15 +66,15 @@ async def _(
     await file_exists(image)
     response: bytes = await execute(
         Path(image).read_bytes(),
-        output_format,
-        dpi,
-        lang,
-        psm,
-        oem,
-        timeout,
-        user_words,
-        user_patterns,
-        tessdata_dir,
+        output_format=output_format,
+        dpi=dpi,
+        psm=psm,
+        oem=oem,
+        timeout=timeout,
+        lang=lang,
+        user_words=user_words,
+        user_patterns=user_patterns,
+        tessdata_dir=tessdata_dir,
     )
     return response
 
