@@ -3,6 +3,7 @@ from pathlib import Path
 import pytest
 
 import aiopytesseract
+from aiopytesseract.exceptions import TesseractRuntimeError
 
 
 @pytest.mark.asyncio
@@ -23,7 +24,7 @@ async def test_image_to_hocr_with_bytes_image(image):
 
 @pytest.mark.asyncio
 async def test_image_to_hocr_with_invalid():
-    with pytest.raises(RuntimeError):
+    with pytest.raises(TesseractRuntimeError):
         await aiopytesseract.image_to_hocr("tests/samples/file-sample_150kB.pdf")
 
 
